# yapp : Yet Another Phasing Program

yapp is a program that includes a set of utilities to work on high
density genetic data in pedigrees. It is similar to other existing
softwares such as LINKPHASE, FIMPUTE, AlphaPhase ... . I
developed it for my own research to have a tool that is opensource and
that I can tweak to my own needs.

If you find it useful for you, drop me a note (*e.g.* on twitter
@BertrandServin). If you want to contribute ideas or code, you are
welcome if you know python :)

yapp and its utilities implement some models and methods that have been
invented by other people. If you use yapp it is important that you
acknowledge their work by citing the appropriate
references. These will depend on the way you use the software, see the
[documentation](https://yapp-doc.netlify.app).
